pyrasa.utils.aperiodic\_utils.compute\_aperiodic\_model\_sprint
===============================================================

.. currentmodule:: pyrasa.utils.aperiodic_utils

.. autofunction:: compute_aperiodic_model_sprint

.. _sphx_glr_backreferences_pyrasa.utils.aperiodic_utils.compute_aperiodic_model_sprint:

.. minigallery:: pyrasa.utils.aperiodic_utils.compute_aperiodic_model_sprint
    :add-heading: